melidosData-package: melidosData: Utilities and example assets for MeLiDos data...

melidosData-packageR Documentation

melidosData: Utilities and example assets for MeLiDos data workflows

Description

The package includes helper functions for working with REDCap codebooks and records, as well as small example datasets and dictionaries for reproducible examples.

Author(s)

Maintainer: Johannes Zauner johannes.zauner@tum.de (ORCID)

Authors:

Other contributors:

  • European Partnership on Metrology (The project (22NRM05 MeLiDos) has received funding from the European Partnership on Metrology, co-financed by the European Union's Horizon Europe Research and Innovation Programme, EURAMET, and the Participating States. Views and opinions expressed are those of the authors and do not necessarily reflect those of the European Union or EURAMET.) [funder]

  • Translational Sensory and Circadian Neuroscience Unit (MPS/TUM/TUMCREATE) (www.tscnlab.org) [copyright holder]

See Also

Useful links:


melidosData documentation built on April 22, 2026, 5:09 p.m.