| flatten_data | R Documentation |
flatten_data() combines the named list returned by load_data() into one
tibble and keeps site provenance in a site column.
flatten_data(melidos_data, tz = "UTC", label_from = 1)
melidos_data |
A list returned by |
tz |
Time zone to enforce for all |
label_from |
indice of the dataset that is used to apply labels to the output. |
If date-time columns are present (POSIXct), their timezone is overwritten
using lubridate::force_tz().
A tibble with all rows stacked and a site column.
example_multi_site <- structure(
list(
TUM = data.frame(id = 1, bedtime = as.POSIXct("2024-01-01 22:00:00", tz = "UTC")),
UCR = data.frame(id = 2, bedtime = as.POSIXct("2024-01-02 22:30:00", tz = "UTC"))
),
class = c("melidos_data", "list")
)
flatten_data(example_multi_site, tz = "Europe/Berlin")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.